mtd/drivers/mtd/nand nand_base.c,1.113,1.114

Kalev Lember kalev at infradead.org
Mon Jul 26 12:07:51 EDT 2004


Update of /home/cvs/mtd/drivers/mtd/nand
In directory phoenix.infradead.org:/tmp/cvs-serv11516

Modified Files:
	nand_base.c 
Log Message:
change return code so that we can distinguish ECC failures from other return codes


Index: nand_base.c
===================================================================
RCS file: /home/cvs/mtd/drivers/mtd/nand/nand_base.c,v
retrieving revision 1.113
retrieving revision 1.114
diff -u -r1.113 -r1.114
--- nand_base.c	14 Jul 2004 16:31:31 -0000	1.113
+++ nand_base.c	26 Jul 2004 16:07:48 -0000	1.114
@@ -1284,12 +1284,12 @@
 	nand_release_chip(mtd);
 
 	/*
 	 * Return success, if no ECC failures, else -EIO
 	 * fs driver will take care of that, because
-	 * retlen == desired len and result == -EIO
+	 * retlen == desired len and result == -EBADMSG
 	 */
 	*retlen = read;
-	return ecc_failed ? -EIO : 0;
+	return ecc_failed ? -EBADMSG : 0;
 }
 
 /**
@@ -1284,12 +1284,12 @@
 
 	/*
-	 * Return success, if no ECC failures, else -EIO
+	 * Return success, if no ECC failures, else -EBADMSG
 	 * fs driver will take care of that, because





More information about the linux-mtd-cvs mailing list